summaryrefslogtreecommitdiff
path: root/svx
diff options
context:
space:
mode:
authorJoseph Powers <jpowers27@cox.net>2011-05-10 05:56:57 -0700
committerJoseph Powers <jpowers27@cox.net>2011-05-10 07:44:41 -0700
commit403be6168f2f49f1a3585990cb98b60f65516b0d (patch)
treede52281603feb3c235d746e026cd46e350accca2 /svx
parent47ce6dbc631082c74578faae11cd534704545640 (diff)
GDIMetaFile cleanup
Plus trailing whitespace cleanup.
Diffstat (limited to 'svx')
-rw-r--r--svx/source/dialog/_bmpmask.cxx6
-rw-r--r--svx/source/svdraw/svdfmtf.cxx10
-rw-r--r--svx/source/svdraw/svdxcgv.cxx4
-rw-r--r--svx/source/xml/xmlgrhlp.cxx2
4 files changed, 11 insertions, 11 deletions
diff --git a/svx/source/dialog/_bmpmask.cxx b/svx/source/dialog/_bmpmask.cxx
index 674b9d18491d..83d9839c1f21 100644
--- a/svx/source/dialog/_bmpmask.cxx
+++ b/svx/source/dialog/_bmpmask.cxx
@@ -830,7 +830,7 @@ GDIMetaFile SvxBmpMask::ImpMask( const GDIMetaFile& rMtf )
}
// Investigate actions and if necessary replace colors
- for( sal_uIntPtr nAct = 0UL, nActCount = rMtf.GetActionCount(); nAct < nActCount; nAct++ )
+ for( size_t nAct = 0, nActCount = rMtf.GetActionSize(); nAct < nActCount; nAct++ )
{
MetaAction* pAction = rMtf.GetAction( nAct );
@@ -1081,7 +1081,7 @@ GDIMetaFile SvxBmpMask::ImpReplaceTransparency( const GDIMetaFile& rMtf, const C
GDIMetaFile aMtf;
const MapMode& rPrefMap = rMtf.GetPrefMapMode();
const Size& rPrefSize = rMtf.GetPrefSize();
- const sal_uIntPtr nActionCount = rMtf.GetActionCount();
+ const size_t nActionCount = rMtf.GetActionSize();
aVDev.EnableOutput( sal_False );
aMtf.Record( &aVDev );
@@ -1093,7 +1093,7 @@ GDIMetaFile SvxBmpMask::ImpReplaceTransparency( const GDIMetaFile& rMtf, const C
// retrieve one action at the time; first
// set the whole area to the replacement color.
aVDev.DrawRect( Rectangle( rPrefMap.GetOrigin(), rPrefSize ) );
- for ( sal_uIntPtr i = 0; i < nActionCount; i++ )
+ for ( size_t i = 0; i < nActionCount; i++ )
{
MetaAction* pAct = rMtf.GetAction( i );
diff --git a/svx/source/svdraw/svdxcgv.cxx b/svx/source/svdraw/svdxcgv.cxx
index d2abe39e9505..d3820eb99181 100644
--- a/svx/source/svdraw/svdxcgv.cxx
+++ b/svx/source/svdraw/svdxcgv.cxx
@@ -603,7 +603,7 @@ GDIMetaFile SdrExchangeView::GetMarkedObjMetaFile( sal_Bool bNoVDevIfOneMtfMarke
}
}
- if( !aMtf.GetActionCount() )
+ if( !aMtf.GetActionSize() )
{
VirtualDevice aOut;
Size aDummySize( 2, 2 );
@@ -708,7 +708,7 @@ Graphic SdrExchangeView::GetObjGraphic( const SdrModel* pModel, const SdrObject*
aMtf.SetPrefMapMode( aMap );
aMtf.SetPrefSize( aBoundRect.GetSize() );
- if( aMtf.GetActionCount() )
+ if( aMtf.GetActionSize() )
aRet = aMtf;
}
}
diff --git a/svx/source/xml/xmlgrhlp.cxx b/svx/source/xml/xmlgrhlp.cxx
index 1e7337b360c7..8288390bfbd7 100644
--- a/svx/source/xml/xmlgrhlp.cxx
+++ b/svx/source/xml/xmlgrhlp.cxx
@@ -74,7 +74,7 @@ const MetaCommentAction* ImplCheckForEPS( GDIMetaFile& rMtf )
static ByteString aComment( (const sal_Char*)"EPSReplacementGraphic" );
const MetaCommentAction* pComment = NULL;
- if ( ( rMtf.GetActionCount() >= 2 )
+ if ( ( rMtf.GetActionSize() >= 2 )
&& ( rMtf.FirstAction()->GetType() == META_EPS_ACTION )
&& ( ((const MetaAction*)rMtf.GetAction( 1 ))->GetType() == META_COMMENT_ACTION )
&& ( ((const MetaCommentAction*)rMtf.GetAction( 1 ))->GetComment() == aComment ) )
diff --git a/svx/source/svdraw/svdfmtf.cxx b/svx/source/svdraw/svdfmtf.cxx
index fe986ef215fa..87eb5c2794b6 100644
--- a/svx/source/svdraw/svdfmtf.cxx
+++ b/svx/source/svdraw/svdfmtf.cxx
@@ -114,7 +114,7 @@ sal_uIntPtr ImpSdrGDIMetaFileImport::DoImport(const GDIMetaFile& rMtf,
pPage = rOL.GetPage();
GDIMetaFile* pTmpMtf=NULL;
GDIMetaFile* pMtf = (GDIMetaFile*) &rMtf;
- sal_uIntPtr nActionAnz=pMtf->GetActionCount();
+ size_t nActionAnz = pMtf->GetActionSize();
sal_Bool bError = sal_False;
@@ -156,7 +156,7 @@ sal_uIntPtr ImpSdrGDIMetaFileImport::DoImport(const GDIMetaFile& rMtf,
if(pProgrInfo)
pProgrInfo->SetActionCount(nActionAnz);
- sal_uIntPtr nActionsToReport = 0;
+ size_t nActionsToReport = 0;
for( MetaAction* pAct = pMtf->FirstAction(); pAct; pAct = pMtf->NextAction() )
{
@@ -223,11 +223,11 @@ sal_uIntPtr ImpSdrGDIMetaFileImport::DoImport(const GDIMetaFile& rMtf,
// Objekte in vorgegebenes Rechteck hineinskalieren
sal_uIntPtr nAnz=aTmpList.GetObjCount();
// Beim berechnen der Fortschrittsanzeige wird GetActionCount()*3 benutzt.
// Da in aTmpList allerdings weniger eintraege als GetActionCount()
// existieren koennen, muessen hier die zuviel vermuteten Actionen wieder
// hinzugefuegt werden.
- nActionsToReport = (pMtf->GetActionCount() - nAnz)*2;
+ nActionsToReport = (pMtf->GetActionSize() - nAnz)*2;
// Alle noch nicht gemeldeten Rescales melden
@@ -223,11 +223,11 @@ sal_uIntPtr ImpSdrGDIMetaFileImport::DoImport(const GDIMetaFile& rMtf,
// Objekte in vorgegebenes Rechteck hineinskalieren
sal_uIntPtr nAnz=aTmpList.GetObjCount();
- // Beim berechnen der Fortschrittsanzeige wird GetActionCount()*3 benutzt.
- // Da in aTmpList allerdings weniger eintraege als GetActionCount()
+ // Beim berechnen der Fortschrittsanzeige wird GetActionSize()*3 benutzt.
+ // Da in aTmpList allerdings weniger eintraege als GetActionSize()
// existieren koennen, muessen hier die zuviel vermuteten Actionen wieder
// hinzugefuegt werden.